==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Usuário"
 ,"Usuários"

]
, "Groups"
: "Grupos"

, "Roles"
: "Funções"

, "Applications"
: "Aplicações"

, "Containers"
: "Repositórios"

, "Shared Tags"
: "Identificações Compartilhadas"

, "Customfields"
: "Campos personalizados"

, "Computers"
: "Computadores"

, "Access Log, Access Logs"
: [
  "Relação de Acesso"
 ,"Relação de Acessos"

]
, "Server Information"
: "Informações do Servidor"

, "ActiveSync Devices"
: ""

, "Admin"
: "Administrador"

, "Refresh"
: "Atualizar"

, "Name"
: "Nome"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Computador"
 ,"Computadores"

]
, "Default Addressbook for new contacts and groups"
: "Catálogo de Endereços padrão para novos contatos e grupos"

, "Group, Groups"
: [
  "Grupo"
 ,"Grupos"

]
, "Application, Applications"
: [
  "Aplicação"
 ,"Aplicações"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Favor aguardar"

, "Updating Memberships"
: "Atualizando Sócios"

, "Failed"
: "Falhou"

, "Could not save group."
: "Grupo não pode ser salvo."

, "Errors"
: "Erros"

, "Please fix the errors noted."
: "Favor fixar os erros anotados."

, "Group Name"
: "Nome do Grupo"

, "Description"
: "Descrição"

, "Visibility"
: "Visibilidade"

, "Display in addressbook"
: "Exibir no catálogo de endereços"

, "Hide from addressbook"
: "Ocultar do catálogo de endereços"

, "Saved in Addressbook"
: "Salvar no Catálogo de Endereços"

, "Group Members"
: "Membros do Grupo"

, "Transferring {0}..."
: "Transferindo {0}..."

, "Add new group"
: "Adicionar novo grupo"

, "Edit Group \"{0}\""
: "Editar Grupo \"{0}\""

, "Enable Application"
: "Permitir Aplicação"

, "Disable Application"
: "Aplicação Bloqueada"

, "Settings"
: "Parâmetros"

, "{0} Settings"
: "{0} Parâmetros"

, "enable application"
: "permitir aplicação"

, "disable application"
: "bloquear aplicação"

, "settings"
: "parâmetros"

, "Search:"
: "Pesquisa:"

, "disabled"
: "inválido"

, "enabled"
: "permitido"

, "unknown status ({0})"
: "situação desconhecida ({0})"

, "Displaying application {0} - {1} of {2}"
: "Exibindo aplicação {0} - {1} de {2}"

, "No applications to display"
: "Nenhuma aplicação a exibir"

, "Order"
: "Ordenar"

, "Status"
: "Situação"

, "Version"
: "Versão"

, "Confirm"
: "Confirmar"

, "Do you really want to delete the selected groups?"
: "Você quer realmente apagar os grupos selecionados?"

, "Deleting group(s)..."
: "Apagando grupo(s)..."

, "Some error occurred while trying to delete the group."
: "Ocorreram alguns erros enquanto tentava apagar o grupo."

, "Add Group"
: "Adicionar Grupo"

, "Edit Group"
: "Editar Grupo"

, "Delete Group"
: "Apagar Grupo"

, "Displaying groups {0} - {1} of {2}"
: "Exibindo grupos {0} - {1} de {2}"

, "No groups to display"
: "Nenhum grupo a exibir"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Nome do Computador"

, "IP Address"
: "Endereço IP"

, "Login Time"
: "Hora da Entrada"

, "Logout Time"
: "Hora de Saída"

, "Client Type"
: "Tipo de Cliente"

, "Session ID"
: "ID da Sessão"

, "Login Name"
: "Nome de Entrada"

, "Result"
: "Resultado"

, "user blocked"
: "usuário bloqueado"

, "password expired"
: "senha expirada"

, "user disabled"
: "usuário inválido"

, "invalid password"
: "senha inválida"

, "ambiguous username"
: "nome de usuário ambíguo"

, "user not found"
: "usuário não encontrado"

, "failure"
: "falha"

, "success"
: "sucesso"

, "Could not save role."
: "Não foi possível salvar a função."

, "Deleting role..."
: "Apagando a função..."

, "Some error occurred while trying to delete the role."
: "Ocorreu algum erro enquanto a função era apagada."

, "Rights"
: "Direitos"

, "Members"
: "Membros"

, "Role Name"
: "Nome da Função"

, "Role"
: "Função"

, "Add New Role"
: "Adicionar Nova Função"

, "Edit Role \"{0}\""
: "Editar Função \"{0}\""

, "Container Name"
: "Nome do Repositório"

, "Type"
: "Tipo"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Repositório"
 ,"Repositórios"

]
, "Model"
: "Modelo"

, "personal"
: "pessoal"

, "shared"
: "compartilhado"

, "Color"
: "Cor"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota para o Proprietário"

, "Do you really want to delete the selected roles?"
: "Você quer realmente apagar as funções selecionadas?"

, "Deleting role(s)..."
: "Apagando função(ões)..."

, "Add Role"
: "Adicionar Função"

, "Edit Role"
: "Editar Função"

, "Delete Role"
: "Apagar Função"

, "Displaying roles {0} - {1} of {2}"
: "Exibindo funções {0} - {1} of {2}"

, "No roles to display"
: "Nenhuma função a exibir"

, "Do you really want to delete the selected tags?"
: "Você quer realmente apagar as identificações selecionadas?"

, "Deleting tag(s)..."
: "Apagando identificação(ões)..."

, "Add Tag"
: "Adicionar Identificação"

, "Edit Tag"
: "Editar Identificação"

, "Delete Tag"
: "Apagar Identificação"

, "Displaying tags {0} - {1} of {2}"
: "Exibindo identificações {0} - {1} of {2}"

, "No tags to display"
: "Nenhuma identificação a exibir"

, "Usage:&#160;"
: "Tratamento:&#160;"

, "Label"
: "Legenda"

, "Value"
: "Valor"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Campo personalizado"
 ,"Campos personalizados"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: "Favor configurar o depósito para este tipo de campo"

, "Record Class"
: "Classe de Registro"

, "Given record class not found"
: "Não foi encontrada a Classe de registro dada"

, "Cancel"
: "Cancelar"

, "OK"
: "OK"

, "Configure store"
: "Configurar armazenamento"

, "Custom field definition"
: "Definição de campo personalizado"

, "Text"
: "Texto"

, "Textarea"
: ""

, "Number"
: "Número"

, "Date"
: "Data"

, "DateTime"
: "Data e Hora"

, "Time"
: "Hora"

, "Boolean"
: "Boleano"

, "Search Combo"
: "Pesquisar Combinação"

, "Key Field"
: "Campo Chave"

, "Record"
: "Registro"

, "Record List"
: ""

, "Length"
: "Comprimento"

, "Required"
: "Requerido"

, "Custom field additional properties"
: "Propriedades adicionais de campo personalizado"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "Campo personalizado já existe. Favor escolher outro nome."

, "Enable Account"
: "Habilitar Conta"

, "Disable Account"
: "Desabilitar Conta"

, "Reset Password"
: "Redefinir Senha"

, "Reset Pin"
: ""

, "Display name"
: "Exibir nome"

, "Login name"
: "Nome de entrada"

, "Last name"
: "Sobrenome"

, "First name"
: "Prenome"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "ID de Abertura"

, "Last login at"
: "Último acesso às"

, "Last login from"
: "Último acesso de"

, "Password changed"
: "Senha modificada"

, "Expires"
: "Expira"

, "Set new password"
: "Definir nova senha"

, "Please enter the new password:"
: "Favor informar nova senha:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Usuários"

, "Samba User, Samba Users"
: [
  "Usuário Samba"
 ,"Usuários Samba"

]
, "Email User, Email Users"
: [
  "Usuário de Email"
 ,"Usuários de Email"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: "Domínio não permitido. Verificar a configação do seu domínio SMTP."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Senhas não são iguais!"

, "Passwords match!"
: "Senhas iguais!"

, "Primary group"
: "Grupo principal"

, "Unix"
: "Unix"

, "Home Directory"
: "Diretório Inicial"

, "Login Shell"
: "Acessar o Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Drive Inicial"

, "Logon Time"
: "Hora da Entrada"

, "never logged in"
: "nunca acessado em"

, "Home Path"
: "Nome do Caminho"

, "Logoff Time"
: "Hora do Desligamento"

, "never logged off"
: "nunca desligado"

, "Profile Path"
: "Caminho do Perfil"

, "Password Last Set"
: "Última Senha"

, "never"
: "nunca"

, "Logon Script"
: "Script de Entrada"

, "Password Can Change"
: "Senha pode mudar"

, "not set"
: "não definido"

, "Password Must Change"
: "Senha deve mudar"

, "Kick Off Time"
: "Hora de início"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "nenhuma quota definida"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Tamanho da Caixa de Correio corrente"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Tamanho do filtro atual"

, "Information"
: "Informação"

, "Last Login"
: "Último Acesso"

, "Domain not allowed"
: "Domínio não permitido"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "Email Alternativo"

, "Add an alias address..."
: "Adicionar um endereço alternativo..."

, "Forwarding to self"
: "Auto encaminhamento"

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: "Não é permitido usar um endereço de email que seja idêntico ao endereço principal dos usuários ou um dos seus pseudônimos."

, "Email Forward"
: "Encaminhar Email"

, "Add a forward address..."
: "Adicionar endereço de encaminhamento..."

, "Forward Only"
: "Somente encaminhar "

, "Password confirmation"
: "Confirmação de senha"

, "Repeat password"
: "Repetir senha"

, "Ok"
: "OK"

, "Account"
: "Conta"

, "Password"
: "Senha"

, "expired"
: "expirado"

, "blocked"
: "bloqueado"

, "Invalid Status"
: "Situação Inválida"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Situação bloqueada só é válida se o usuário tentou entrar com um senha errada frequentemente. Não é possível atribuir esta situação aqui."

, "don't know"
: "não sei"

, "Password set"
: "Definir senha"

, "User groups"
: "Grupos de Usuários"

, "User roles"
: "Função do usuário"

, "Fileserver"
: "Servidor de arquivo"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Atualizando Identificação"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Contextos Permitidos"

, "Context"
: "Contexto"

, "Account Rights"
: "Direitos de Conta"

, "View"
: "Visões"

, "Use"
: "Usar"

, "Tag Name"
: "Nome da Identificação"

, "Tag"
: "Identificação"

, "Add New Tag"
: "Adicionar Nova Identificação"

, "Edit Tag \"{0}\""
: "Editar Identificação  \"{0}\""

, "Default IMAP user settings"
: "Parâmetros padrão de usuário IMAP"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "gerenciar a lista de acesso"

, "delete access log entries"
: "apagar as entradas da lista de acesso"

, "manage accounts"
: "gerenciar contas"

, "add and edit users and groups, add group members, change user passwords"
: "adicionar e editar usuários e grupos, adicionar membros de grupos, modificar senhas de usuários"

, "manage applications"
: "gerenciar aplicações"

, "enable and disable applications, edit application settings"
: "permitir e restringir aplicações, editar parâmetros de aplicações"

, "manage roles"
: "gerenciar funções"

, "add and edit roles, add new members to roles, add application rights to roles"
: "adicionar e editar funções, adicionar novos membros em funções, \" \"adicionar privilégios a funções"

, "manage shared tags"
: "gerenciar identificações compartilhadas"

, "add, delete and edit shared tags"
: "adicionar, apagar e editar identificações compartilhadas"

, "manage computers"
: "gerenciar computadores"

, "add, delete and edit (samba) computers"
: "adicionar, apagar e editar (samba) computadores"

, "manage containers"
: "gerenciar repositórios"

, "add, delete and edit containers and manage container grants"
: "adicionar, apagar e editar repositórios e gerenciar privilégios \" \"sobre repositórios"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "ver a lista de acesso"

, "view access log list"
: "ver a relação das listas de acesso"

, "view accounts"
: "ver contas"

, "view accounts list and details"
: "ver lista de contas e detalhes"

, "view applications"
: "ver aplicações"

, "view applications list and details"
: "ver lista de aplicações e detalhes"

, "view roles"
: "ver funções"

, "view roles list and details"
: "ver lista de funções e detalhes"

, "view computers"
: "ver computadores"

, "view computers list and details"
: "ver lista de computadores e detalhes"

, "view containers"
: "ver repositórios"

, "view personal and shared containers"
: "ver repositórios pessoais e compartilhados"

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: "Seu repositório foi modificado"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Seu repositório foi modificado por %1$s %2$sNota: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Usuário"

, "Access Log"
: "Relação de Acesso"

, "Computer"
: "Computador"

, "Group"
: "Grupo"

, "Application"
: "Aplicação"

, "Config"
: ""

, "Container"
: "Repositório"

, "Customfield"
: "Campo personalizado"

, "Samba User"
: "Usuário Samba"

, "Email User"
: "Usuário de Email"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Permitir Aplicação"

, "Disable Application"
: "Aplicação Bloqueada"

, "Settings"
: "Parâmetros"

, "{0} Settings"
: "{0} Parâmetros"

, "Search:"
: "Pesquisa:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Exibindo aplicação {0} - {1} de {2}"

, "No applications to display"
: "Nenhuma aplicação a exibir"

, "Order"
: "Ordenar"

, "Name"
: "Nome"

, "Status"
: "Situação"

, "Version"
: "Versão"

, "Confirm"
: "Confirmar"

, "Do you really want to delete the selected groups?"
: "Você quer realmente apagar os grupos selecionados?"

, "Deleting group(s)..."
: "Apagando grupo(s)..."

, "Failed"
: "Falhou"

, "Some error occurred while trying to delete the group."
: "Ocorreram alguns erros enquanto tentava apagar o grupo."

, "Add Group"
: "Adicionar Grupo"

, "Edit Group"
: "Editar Grupo"

, "Delete Group"
: "Apagar Grupo"

, "Displaying groups {0} - {1} of {2}"
: "Exibindo grupos {0} - {1} de {2}"

, "No groups to display"
: "Nenhum grupo a exibir"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Descrição"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Erros"

, "Please configure store for this field type"
: "Favor configurar o depósito para este tipo de campo"

, "Application, Applications"
: [
  "Aplicação"
 ,"Aplicações"

]
, "Record Class"
: "Classe de Registro"

, "Given record class not found"
: "Não foi encontrada a Classe de registro dada"

, "Cancel"
: "Cancelar"

, "OK"
: "OK"

, "Configure store"
: "Configurar armazenamento"

, "Model"
: "Modelo"

, "Custom field definition"
: "Definição de campo personalizado"

, "Text"
: "Texto"

, "Textarea"
: ""

, "Number"
: "Número"

, "Date"
: "Data"

, "DateTime"
: "Data e Hora"

, "Time"
: "Hora"

, "Boolean"
: "Boleano"

, "Search Combo"
: "Pesquisar Combinação"

, "Key Field"
: "Campo Chave"

, "Record"
: "Registro"

, "Record List"
: ""

, "Type"
: "Tipo"

, "Label"
: "Legenda"

, "Length"
: "Comprimento"

, "Required"
: "Requerido"

, "Custom field additional properties"
: "Propriedades adicionais de campo personalizado"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grupo"
 ,"Grupos"

]
, "Customfield already exists. Please choose another name."
: "Campo personalizado já existe. Favor escolher outro nome."

, "Customfield, Customfields"
: [
  "Campo personalizado"
 ,"Campos personalizados"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Valor"

, "Default ({0})"
: ""

, "Computer Name"
: "Nome do Computador"

, "Default Addressbook for new contacts and groups"
: "Catálogo de Endereços padrão para novos contatos e grupos"

, "Please wait"
: "Favor aguardar"

, "Updating Tag"
: "Atualizando Identificação"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Favor fixar os erros anotados."

, "Allowed Contexts"
: "Contextos Permitidos"

, "Context"
: "Contexto"

, "Account Rights"
: "Direitos de Conta"

, "View"
: "Visões"

, "Use"
: "Usar"

, "Tag Name"
: "Nome da Identificação"

, "Color"
: "Cor"

, "Transferring {0}..."
: "Transferindo {0}..."

, "Tag"
: "Identificação"

, "Add New Tag"
: "Adicionar Nova Identificação"

, "Edit Tag \"{0}\""
: "Editar Identificação  \"{0}\""

, "Do you really want to delete the selected tags?"
: "Você quer realmente apagar as identificações selecionadas?"

, "Deleting tag(s)..."
: "Apagando identificação(ões)..."

, "Add Tag"
: "Adicionar Identificação"

, "Edit Tag"
: "Editar Identificação"

, "Delete Tag"
: "Apagar Identificação"

, "Displaying tags {0} - {1} of {2}"
: "Exibindo identificações {0} - {1} of {2}"

, "No tags to display"
: "Nenhuma identificação a exibir"

, "Usage:&#160;"
: "Tratamento:&#160;"

, "Updating Memberships"
: "Atualizando Sócios"

, "Could not save role."
: "Não foi possível salvar a função."

, "Deleting role..."
: "Apagando a função..."

, "Some error occurred while trying to delete the role."
: "Ocorreu algum erro enquanto a função era apagada."

, "Rights"
: "Direitos"

, "Members"
: "Membros"

, "Role Name"
: "Nome da Função"

, "Role"
: "Função"

, "Add New Role"
: "Adicionar Nova Função"

, "Edit Role \"{0}\""
: "Editar Função \"{0}\""

, "Do you really want to delete the selected roles?"
: "Você quer realmente apagar as funções selecionadas?"

, "Deleting role(s)..."
: "Apagando função(ões)..."

, "Add Role"
: "Adicionar Função"

, "Edit Role"
: "Editar Função"

, "Delete Role"
: "Apagar Função"

, "Displaying roles {0} - {1} of {2}"
: "Exibindo funções {0} - {1} of {2}"

, "No roles to display"
: "Nenhuma função a exibir"

, "Access Log, Access Logs"
: [
  "Relação de Acesso"
 ,"Relação de Acessos"

]
, "Groups"
: "Grupos"

, "Applications"
: "Aplicações"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domínio não permitido. Verificar a configação do seu domínio SMTP."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Senhas não são iguais!"

, "Passwords match!"
: "Senhas iguais!"

, "Primary group"
: "Grupo principal"

, "Unix"
: "Unix"

, "Home Directory"
: "Diretório Inicial"

, "Login Shell"
: "Acessar o Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Drive Inicial"

, "Login Time"
: "Hora da Entrada"

, "never logged in"
: "nunca acessado em"

, "Home Path"
: "Nome do Caminho"

, "Logout Time"
: "Hora de Saída"

, "never logged off"
: "nunca desligado"

, "Profile Path"
: "Caminho do Perfil"

, "Password Last Set"
: "Última Senha"

, "never"
: "nunca"

, "Logon Script"
: "Script de Entrada"

, "Password Can Change"
: "Senha pode mudar"

, "not set"
: "não definido"

, "Password Must Change"
: "Senha deve mudar"

, "Kick Off Time"
: "Hora de início"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "nenhuma quota definida"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Tamanho da Caixa de Correio corrente"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Tamanho do filtro atual"

, "Information"
: "Informação"

, "Last Login"
: "Último Acesso"

, "Domain not allowed"
: "Domínio não permitido"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Adicionar um endereço alternativo..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: "Auto encaminhamento"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Somente encaminhar "

, "Password confirmation"
: "Confirmação de senha"

, "Repeat password"
: "Repetir senha"

, "Ok"
: "OK"

, "Account"
: "Conta"

, "First name"
: "Prenome"

, "Last name"
: "Sobrenome"

, "Login name"
: "Nome de entrada"

, "Password"
: "Senha"

, "OpenID"
: "ID de Abertura"

, "enabled"
: "permitido"

, "disabled"
: "inválido"

, "expired"
: "expirado"

, "blocked"
: "bloqueado"

, "Invalid Status"
: "Situação Inválida"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Situação bloqueada só é válida se o usuário tentou entrar com um senha errada frequentemente. Não é possível atribuir esta situação aqui."

, "Expires"
: "Expira"

, "Visibility"
: "Visibilidade"

, "Display in addressbook"
: "Exibir no catálogo de endereços"

, "Hide from addressbook"
: "Ocultar do catálogo de endereços"

, "Saved in Addressbook"
: "Salvar no Catálogo de Endereços"

, "Last login at"
: "Último acesso às"

, "don't know"
: "não sei"

, "Last login from"
: "Último acesso de"

, "Password set"
: "Definir senha"

, "User groups"
: "Grupos de Usuários"

, "User roles"
: "Função do usuário"

, "Fileserver"
: "Servidor de arquivo"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Usuário"
 ,"Usuários"

]
, "Users"
: "Usuários"

, "Samba User, Samba Users"
: [
  "Usuário Samba"
 ,"Usuários Samba"

]
, "Email User, Email Users"
: [
  "Usuário de Email"
 ,"Usuários de Email"

]
, "Enable Account"
: "Habilitar Conta"

, "Disable Account"
: "Desabilitar Conta"

, "Reset Password"
: "Redefinir Senha"

, "Reset Pin"
: ""

, "Display name"
: "Exibir nome"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Senha modificada"

, "Set new password"
: "Definir nova senha"

, "Please enter the new password:"
: "Favor informar nova senha:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nome do Grupo"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membros do Grupo"

, "personal"
: "pessoal"

, "shared"
: "compartilhado"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota para o Proprietário"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Repositório"
 ,"Repositórios"

]
, "Container Name"
: "Nome do Repositório"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Computador"
 ,"Computadores"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Funções"

, "Containers"
: "Repositórios"

, "Shared Tags"
: "Identificações Compartilhadas"

, "Customfields"
: "Campos personalizados"

, "Computers"
: "Computadores"

, "Server Information"
: "Informações do Servidor"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Administrador"

, "Refresh"
: "Atualizar"

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "Endereço IP"

, "Client Type"
: "Tipo de Cliente"

, "Session ID"
: "ID da Sessão"

, "Login Name"
: "Nome de Entrada"

, "Result"
: "Resultado"

, "user blocked"
: "usuário bloqueado"

, "password expired"
: "senha expirada"

, "user disabled"
: "usuário inválido"

, "invalid password"
: "senha inválida"

, "ambiguous username"
: "nome de usuário ambíguo"

, "user not found"
: "usuário não encontrado"

, "failure"
: "falha"

, "success"
: "sucesso"

, "Default IMAP user settings"
: "Parâmetros padrão de usuário IMAP"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Seu repositório foi modificado"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Seu repositório foi modificado por %1$s %2$sNota: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""









































, "Application"
: "Aplicação"

, "Group"
: "Grupo"

, "Customfield"
: "Campo personalizado"

, "Config"
: ""

, "Access Log"
: "Relação de Acesso"

, "User"
: "Usuário"

, "Samba User"
: "Usuário Samba"

, "Email User"
: "Usuário de Email"

, "Container"
: "Repositório"

, "Computer"
: "Computador"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
